@@ -102,6 +102,7 @@ class CausalSGU(nn.Module):
         nn.init.uniform_(self.weight, -init_eps, init_eps)
         nn.init.constant_(self.bias, 1.)
 
+        self.act = act
         self.register_buffer('mask', ~torch.ones(dim_seq, dim_seq).triu_(1).bool())
 
     def forward(self, x):
@@ -120,7 +121,7 @@ class CausalSGU(nn.Module):
         gate = gate + rearrange(bias, 'h n -> () h n ()')
         gate = rearrange(gate, 'b h n d -> b n (h d)')
 
-        return gate * res
+        return self.act(gate) * res
 
 class CausalLocalSGU(nn.Module):
     def __init__(
